@@ -52,27 +52,18 @@ class _Dialect(type):
         klass.parser_class = getattr(klass, "Parser", Parser)
         klass.generator_class = getattr(klass, "Generator", Generator)
 
-        identifiers = dict(
-            (identifier[0], identifier[1])
-            if isinstance(identifier, tuple)
-            else (identifier, identifier)
-            for identifier in klass.identifiers
-        )
-        klass.identifier_start, klass.identifier_end = list(identifiers.items())[0]
-
-        klass.tokenizer = klass.tokenizer_class(
-            identifiers=identifiers,
-            escape=klass.escape,
-        )
+        klass.tokenizer = klass.tokenizer_class()
+        klass.quote_start, klass.quote_end = list(klass.tokenizer_class.QUOTES.items())[
+            0
+        ]
+        klass.identifier_start, klass.identifier_end = list(
+            klass.tokenizer_class.IDENTIFIERS.items()
+        )[0]
 
         return klass
 
 
 class Dialect(metaclass=_Dialect):
-    identifiers = ['"']
-    identifier_start = '"'
-    identifier_end = '"'
-    escape = "'"
     index_offset = 0
     unnest_column_only = False
     alias_post_tablesample = False
@@ -85,6 +76,11 @@ class Dialect(metaclass=_Dialect):
     time_mapping = {}
 
     # autofilled
+    quote_start = None
+    quote_end = None
+    identifier_start = None
+    identifier_end = None
+
     time_trie = None
     inverse_time_mapping = None
     inverse_time_trie = None
@@ -112,7 +108,7 @@ class Dialect(metaclass=_Dialect):
                     cls.time_trie,
                 )
             )
-        if isinstance(expression, exp.Literal) and expression.is_string:
+        if expression and expression.is_string:
             return exp.Literal.string(
                 format_time(
                     expression.this,
@@ -137,7 +133,6 @@ class Dialect(metaclass=_Dialect):
         return self.generate(self.parse(code), **opts)
 
     def parser(self, **opts):
-        # pylint: disable=not-callable
         return self.parser_class(
             **{
                 "index_offset": self.index_offset,
@@ -149,13 +144,13 @@ class Dialect(metaclass=_Dialect):
         )
 
     def generator(self, **opts):
-        # pylint: disable=not-callable
         return self.generator_class(
             **{
-                "quote": self.tokenizer_class.QUOTES[0],
+                "quote_start": self.quote_start,
+                "quote_end": self.quote_end,
                 "identifier_start": self.identifier_start,
                 "identifier_end": self.identifier_end,
-                "escape": self.escape,
+                "escape": self.tokenizer_class.ESCAPE,
                 "index_offset": self.index_offset,
                 "time_mapping": self.inverse_time_mapping,
                 "time_trie": self.inverse_time_trie,
