@@ -267,6 +267,14 @@ class Expression(metaclass=_Expression):
             expression = expression.this
         return expression
 
+    def unalias(self):
+        """
+        Returns the inner expression if this is an Alias.
+        """
+        if isinstance(self, Alias):
+            return self.this
+        return self
+
     def unnest_operands(self):
         """
         Returns unnested operands as a tuple.
@@ -743,6 +751,10 @@ class Join(Expression):
     def side(self):
         return self.text("side").upper()
 
+    @property
+    def alias_or_name(self):
+        return self.this.alias_or_name
+
     def on(self, *expressions, append=True, dialect=None, copy=True, **opts):
         """
         Append to or set the ON expressions.
@@ -1155,6 +1167,72 @@ class Select(Subqueryable, Expression):
             **opts,
         )
 
+    def sort_by(self, *expressions, append=True, dialect=None, copy=True, **opts):
+        """
+        Set the SORT BY expression.
+
+        Example:
+            >>> Select().from_("tbl").select("x").sort_by("x DESC").sql()
+            'SELECT x FROM tbl SORT BY x DESC'
+
+        Args:
+            *expressions (str or Expression): the SQL code strings to parse.
+                If a `Group` instance is passed, this is used as-is.
+                If another `Expression` instance is passed, it will be wrapped in a `SORT`.
+            append (bool): if `True`, add to any existing expressions.
+                Otherwise, this flattens all the `Order` expression into a single expression.
+            dialect (str): the dialect used to parse the input expression.
+            copy (bool): if `False`, modify this expression instance in-place.
+            opts (kwargs): other options to use to parse the input expressions.
+
+        Returns:
+            Select: the modified expression.
+        """
+        return _apply_child_list_builder(
+            *expressions,
+            instance=self,
+            arg="sort",
+            append=append,
+            copy=copy,
+            prefix="SORT BY",
+            into=Sort,
+            dialect=dialect,
+            **opts,
+        )
+
+    def cluster_by(self, *expressions, append=True, dialect=None, copy=True, **opts):
+        """
+        Set the CLUSTER BY expression.
+
+        Example:
+            >>> Select().from_("tbl").select("x").cluster_by("x DESC").sql()
+            'SELECT x FROM tbl CLUSTER BY x DESC'
+
+        Args:
+            *expressions (str or Expression): the SQL code strings to parse.
+                If a `Group` instance is passed, this is used as-is.
+                If another `Expression` instance is passed, it will be wrapped in a `Cluster`.
+            append (bool): if `True`, add to any existing expressions.
+                Otherwise, this flattens all the `Order` expression into a single expression.
+            dialect (str): the dialect used to parse the input expression.
+            copy (bool): if `False`, modify this expression instance in-place.
+            opts (kwargs): other options to use to parse the input expressions.
+
+        Returns:
+            Select: the modified expression.
+        """
+        return _apply_child_list_builder(
+            *expressions,
+            instance=self,
+            arg="cluster",
+            append=append,
+            copy=copy,
+            prefix="CLUSTER BY",
+            into=Cluster,
+            dialect=dialect,
+            **opts,
+        )
+
     def limit(self, expression, dialect=None, copy=True, **opts):
         """
         Set the LIMIT expression.
@@ -1588,6 +1666,7 @@ class DataType(Expression):
         DECIMAL = auto()
         BOOLEAN = auto()
         JSON = auto()
+        INTERVAL = auto()
         TIMESTAMP = auto()
         TIMESTAMPTZ = auto()
         DATE = auto()
@@ -1949,10 +2028,18 @@ class ArraySum(Func):
     pass
 
 
+class ArrayUnionAgg(AggFunc):
+    pass
+
+
 class Avg(AggFunc):
     pass
 
 
+class AnyValue(AggFunc):
+    pass
+
+
 class Case(Func):
     arg_types = {"this": False, "ifs": True, "default": False}
 
@@ -2108,6 +2195,11 @@ class If(Func):
     arg_types = {"this": True, "true": True, "false": False}
 
 
+class IfNull(Func):
+    arg_types = {"this": True, "expression": False}
+    _sql_names = ["IFNULL", "NVL"]
+
+
 class Initcap(Func):
     pass
 
@@ -2178,6 +2270,10 @@ class Month(Func):
     pass
 
 
+class Nvl2(Func):
+    arg_types = {"this": True, "true": True, "false": False}
+
+
 class Posexplode(Func):
     pass
 
@@ -2223,8 +2319,10 @@ class Split(Func):
     arg_types = {"this": True, "expression": True}
 
 
+# Start may be omitted in the case of postgres
+# https://www.postgresql.org/docs/9.1/functions-string.html @ Table 9-6
 class Substring(Func):
-    arg_types = {"this": True, "start": True, "length": False}
+    arg_types = {"this": True, "start": False, "length": False}
 
 
 class StrPosition(Func):
@@ -2296,6 +2394,15 @@ class TimeStrToUnix(Func):
     pass
 
 
+class Trim(Func):
+    arg_types = {
+        "this": True,
+        "position": False,
+        "expression": False,
+        "collation": False,
+    }
+
+
 class TsOrDsAdd(Func, TimeUnit):
     arg_types = {"this": True, "expression": True, "unit": False}
 
@@ -2333,15 +2440,11 @@ class Upper(Func):
 
 
 class Variance(AggFunc):
-    pass
+    _sql_names = ["VARIANCE", "VARIANCE_SAMP", "VAR_SAMP"]
 
 
 class VariancePop(AggFunc):
-    pass
-
-
-class VarianceSamp(AggFunc):
-    pass
+    _sql_names = ["VARIANCE_POP", "VAR_POP"]
 
 
 class Week(Func):
